"""Functionality for working with Legendre bases"""
from . import la
from .bases import *
from .matrices import *
#from .fastgl import fastgl_wrap
